# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "%d min oor om te lees",
    "(active)": "(aktief)",
    "Also available in:": "Ook beskikbaar in:",
    "Archive": "Argief",
    "Atom feed": "Atom-voer",
    "Authors": "Outeurs",
    "Categories": "Kategorieë",
    "Comments": "Opmerkings",
    "LANGUAGE": "Afrikaans",
    "Languages:": "Tale:",
    "More posts about %s": "Meer plasings oor %s",
    "Newer posts": "Jonger plasings",
    "Next post": "Volgende plasing",
    "Next": "Volgende",
    "No posts found.": "Geen plasings gevind nie.",
    "Nothing found.": "Niks gevind nie.",
    "Older posts": "Ouer plasings",
    "Original site": "Oorspronklike werf",
    "Posted:": "Geplaas:",
    "Posts about %s": "Plasings oor %s",
    "Posts by %s": "Plasings deur %s",
    "Posts for year %s": "Plasings vir %s",
    "Posts for {month_day_year}": "Plasings vir {month_day_year}",
    "Posts for {month_year}": "Plasings vir {month_year}",
    "Previous post": "Vorige plasing",
    "Previous": "Vorige",
    "Publication date": "Publikasiedatum",
    "RSS feed": "RSS-voer",
    "Read in English": "Lees in Afrikaans",
    "Read more": "Lees meer",
    "Skip to main content": "Spring na die hoofinhoud",
    "Source": "Bron",
    "Subcategories:": "Subkategorieë:",
    "Tags and Categories": "Etikette en kategorieë",
    "Tags": "Etikette",
    "Toggle navigation": "Wissel navigasie",
    "Uncategorized": "Ongekategoriseerd",
    "Up": "Op",
    "Updates": "Bywerkings",
    "Write your page here.": "Skryf die bladsy hier.",
    "Write your post here.": "Skryf die plasing hier.",
    "old posts, page %d": "ou plasings, bladsy %d",
    "page %d": "bladsy %d",
    "updated": "bygewerk",
}



# -*- coding: utf-8 -*-

# Copyright © 2012-2024 Roberto Alsina and others.

# Permission is hereby granted, free of charge, to any
# person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the
# Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all copies or substantial portions of
# the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
# OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""Classify the posts in archives."""

import datetime
from collections import defaultdict

import natsort

import nikola.utils
from nikola.plugin_categories import Taxonomy


class Archive(Taxonomy):
    """Classify the post archives."""

    name = "classify_archive"

    classification_name = "archive"
    overview_page_variable_name = "archive"
    more_than_one_classifications_per_post = False
    has_hierarchy = True
    include_posts_from_subhierarchies = True
    include_posts_into_hierarchy_root = True
    subcategories_list_template = "list.tmpl"
    template_for_classification_overview = None
    always_disable_rss = True
    always_disable_atom = True
    apply_to_posts = True
    apply_to_pages = False
    minimum_post_count_per_classification_in_overview = 1
    omit_empty_classifications = False
    add_other_languages_variable = True
    path_handler_docstrings = {
        'archive_index': False,
        'archive': """Link to archive path, name is the year.

        Example:

        link://archive/2013 => /archives/2013/index.html""",
        'archive_atom': False,
        'archive_rss': False,
    }

    def set_site(self, site):
        """Set Nikola site."""
        # Sanity checks
        if (site.config['CREATE_MONTHLY_ARCHIVE'] and site.config['CREATE_SINGLE_ARCHIVE']) and not site.config['CREATE_FULL_ARCHIVES']:
            raise Exception('Cannot create monthly and single archives at the same time.')
        # Finish setup
        self.show_list_as_subcategories_list = not site.config['CREATE_FULL_ARCHIVES']
        self.show_list_as_index = site.config['ARCHIVES_ARE_INDEXES']
        self.template_for_single_list = "archiveindex.tmpl" if site.config['ARCHIVES_ARE_INDEXES'] else "archive.tmpl"
        # Determine maximum hierarchy height
        if site.config['CREATE_DAILY_ARCHIVE'] or site.config['CREATE_FULL_ARCHIVES']:
            self.max_levels = 3
        elif site.config['CREATE_MONTHLY_ARCHIVE']:
            self.max_levels = 2
        elif site.config['CREATE_SINGLE_ARCHIVE']:
            self.max_levels = 0
        else:
            self.max_levels = 1
        return super().set_site(site)

    def get_implicit_classifications(self, lang):
        """Return a list of classification strings which should always appear in posts_per_classification."""
        return ['']

    def classify(self, post, lang):
        """Classify the given post for the given language."""
        levels = [str(post.date.year).zfill(4), str(post.date.month).zfill(2), str(post.date.day).zfill(2)]
        return ['/'.join(levels[:self.max_levels])]

    def sort_classifications(self, classifications, lang, level=None):
        """Sort the given list of classification strings."""
        if level in (0, 1):
            # Years or months: sort descending
            classifications.sort()
            classifications.reverse()

    def get_classification_friendly_name(self, classification, lang, only_last_component=False):
        """Extract a friendly name from the classification."""
        classification = self.extract_hierarchy(classification)
        if len(classification) == 0:
            return self.site.MESSAGES[lang]['Archive']
        elif len(classification) == 1:
            return classification[0]
        elif len(classification) == 2:
            if only_last_component:
                date_str = "{month}"
            else:
                date_str = "{month_year}"
            return nikola.utils.LocaleBorg().format_date_in_string(
                date_str,
                datetime.date(int(classification[0]), int(classification[1]), 1),
                lang)
        else:
            if only_last_component:
                return str(classification[2])
            return nikola.utils.LocaleBorg().format_date_in_string(
                "{month_day_year}",
                datetime.date(int(classification[0]), int(classification[1]), int(classification[2])),
                lang)

    def get_path(self, classification, lang, dest_type='page'):
        """Return a path for the given classification."""
        components = [self.site.config['ARCHIVE_PATH'](lang)]
        if classification:
            components.extend(classification)
            add_index = 'always'
        else:
            components.append(self.site.config['ARCHIVE_FILENAME'](lang))
            add_index = 'never'
        return [_f for _f in components if _f], add_index

    def extract_hierarchy(self, classification):
        """Given a classification, return a list of parts in the hierarchy."""
        return classification.split('/') if classification else []

    def recombine_classification_from_hierarchy(self, hierarchy):
        """Given a list of parts in the hierarchy, return the classification string."""
        return '/'.join(hierarchy)

    def provide_context_and_uptodate(self, classification, lang, node=None):
        """Provide data for the context and the uptodate list for the list of the given classifiation."""
        hierarchy = self.extract_hierarchy(classification)
        kw = {
            "messages": self.site.MESSAGES,
        }
        page_kind = "list"
        if self.show_list_as_index:
            if not self.show_list_as_subcategories_list or len(hierarchy) == self.max_levels:
                page_kind = "index"
        if len(hierarchy) == 0:
            title = kw["messages"][lang]["Archive"]
        elif len(hierarchy) == 1:
            title = kw["messages"][lang]["Posts for year %s"] % hierarchy[0]
        elif len(hierarchy) == 2:
            title = nikola.utils.LocaleBorg().format_date_in_string(
                kw["messages"][lang]["Posts for {month_year}"],
                datetime.date(int(hierarchy[0]), int(hierarchy[1]), 1),
                lang)
        elif len(hierarchy) == 3:
            title = nikola.utils.LocaleBorg().format_date_in_string(
                kw["messages"][lang]["Posts for {month_day_year}"],
                datetime.date(int(hierarchy[0]), int(hierarchy[1]), int(hierarchy[2])),
                lang)
        else:
            raise Exception("Cannot interpret classification {}!".format(repr(classification)))

        context = {
            "title": title,
            "pagekind": [page_kind, "archive_page"],
            "create_archive_navigation": self.site.config["CREATE_ARCHIVE_NAVIGATION"],
            "archive_name": classification
        }

        # Generate links for hierarchies
        if context["create_archive_navigation"]:
            if hierarchy:
                # Up level link makes sense only if this is not the top-level
                # page (hierarchy is empty)
                parent = '/'.join(hierarchy[:-1])
                context["up_archive"] = self.site.link('archive', parent, lang)
                context["up_archive_name"] = self.get_classification_friendly_name(parent, lang)
            else:
                context["up_archive"] = None
                context["up_archive_name"] = None

            nodelevel = len(hierarchy)
            flat_samelevel = self.archive_navigation[lang][nodelevel]
            idx = flat_samelevel.index(classification)
            if idx == -1:
                raise Exception("Cannot find classification {0} in flat hierarchy!".format(classification))
            previdx, nextidx = idx - 1, idx + 1
            # If the previous index is -1, or the next index is 1, the previous/next archive does not exist.
            context["previous_archive"] = self.site.link('archive', flat_samelevel[previdx], lang) if previdx != -1 else None
            context["previous_archive_name"] = self.get_classification_friendly_name(flat_samelevel[previdx], lang) if previdx != -1 else None
            context["next_archive"] = self.site.link('archive', flat_samelevel[nextidx], lang) if nextidx != len(flat_samelevel) else None
            context["next_archive_name"] = self.get_classification_friendly_name(flat_samelevel[nextidx], lang) if nextidx != len(flat_samelevel) else None
            context["archive_nodelevel"] = nodelevel
            context["has_archive_navigation"] = bool(context["previous_archive"] or context["up_archive"] or context["next_archive"])
        else:
            context["has_archive_navigation"] = False
        kw.update(context)
        return context, kw

    def postprocess_posts_per_classification(self, posts_per_classification_per_language, flat_hierarchy_per_lang=None, hierarchy_lookup_per_lang=None):
        """Rearrange, modify or otherwise use the list of posts per classification and per language."""
        # Build a lookup table for archive navigation, if we’ll need one.
        if self.site.config['CREATE_ARCHIVE_NAVIGATION']:
            if flat_hierarchy_per_lang is None:
                raise ValueError('Archives need flat_hierarchy_per_lang')
            self.archive_navigation = {}
            for lang, flat_hierarchy in flat_hierarchy_per_lang.items():
                self.archive_navigation[lang] = defaultdict(list)
                for node in flat_hierarchy:
                    if not self.site.config["SHOW_UNTRANSLATED_POSTS"]:
                        if not [x for x in posts_per_classification_per_language[lang][node.classification_name] if x.is_translation_available(lang)]:
                            continue
                    self.archive_navigation[lang][len(node.classification_path)].append(node.classification_name)

                # We need to sort it. Natsort means it’s year 10000 compatible!
                for k, v in self.archive_navigation[lang].items():
                    self.archive_navigation[lang][k] = natsort.natsorted(v, alg=natsort.ns.F | natsort.ns.IC)

        return super().postprocess_posts_per_classification(posts_per_classification_per_language, flat_hierarchy_per_lang, hierarchy_lookup_per_lang)

    def should_generate_classification_page(self, classification, post_list, lang):
        """Only generates list of posts for classification if this function returns True."""
        return classification == '' or len(post_list) > 0

    def get_other_language_variants(self, classification, lang, classifications_per_language):
        """Return a list of variants of the same classification in other languages."""
        return [(other_lang, classification) for other_lang, lookup in classifications_per_language.items() if classification in lookup and other_lang != lang]



# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "a restin altris %d minûts di leture",
    "(active)": "(atîf)",
    "Also available in:": "Disponibil ancje in:",
    "Archive": "Archivi",
    "Atom feed": "Feed Atom",
    "Authors": "Autôrs",
    "Categories": "Categoriis",
    "Comments": "Coments",
    "LANGUAGE": "Furlan",
    "Languages:": "Lenghis:",
    "More posts about %s": "Altris articui su %s",
    "Newer posts": "Articui plui resints",
    "Next post": "Prossim articul",
    "Next": "Prossim",
    "No posts found.": "Nissun articul cjatât.",
    "Nothing found.": "Nol è stât cjatât nuie.",
    "Older posts": "Articui precedents",
    "Original site": "Sît originâl",
    "Posted:": "Publicât:",
    "Posts about %s": "Articui su %s",
    "Posts by %s": "Articui di %s",
    "Posts for year %s": "Articui par an %s",
    "Posts for {month_day_year}": "Articui par {month_day_year}",
    "Posts for {month_year}": "Articui par {month_year}",
    "Previous post": "Articul precedent",
    "Previous": "Precedent",
    "Publication date": "Date di publicazion",
    "RSS feed": "Feed RSS",
    "Read in English": "Lei par furlan",
    "Read more": "Continue la leture",
    "Skip to main content": "Va al test principâl",
    "Source": "Document origjinâl",
    "Subcategories:": "Subcategoriis:",
    "Tags and Categories": "Tags e categoriis",
    "Tags": "Tags",
    "Toggle navigation": "Ativâ la navigazion",
    "Uncategorized": "Cence categorie",
    "Up": "Su",
    "Updates": "Inzornaments",
    "Write your page here.": "Scrîf ca la tô pagjine.",
    "Write your post here.": "Scrîf ca il to articul.",
    "old posts, page %d": "articui vecjos, pagjine %d",
    "page %d": "pagjine %d",
    "updated": "inzornât",
}



# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "残りを読むのに必要な時間は%d分",
    "(active)": "(有効)",
    "Also available in:": "他の言語で読む：",
    "Archive": "過去記事一覧",
    "Atom feed": "Atomフィード",
    "Authors": "著者一覧",
    "Categories": "カテゴリー",
    "Comments": "コメント",
    "LANGUAGE": "日本語",
    "Languages:": "言語：",
    "More posts about %s": "%sに関する記事一覧",
    "Newer posts": "新しい記事",
    "Next post": "次の記事",
    "Next": "次へ",
    "No posts found.": "記事はありません。",
    "Nothing found.": "なにも見つかりませんでした。",
    "Older posts": "過去の記事",
    "Original site": "元のサイト",
    "Posted:": "公開日時：",
    "Posts about %s": "%sについての記事",
    "Posts by %s": "%sの記事一覧",
    "Posts for year %s": "%s年の記事",
    "Posts for {month_day_year}": "{month_day_year}の記事",
    "Posts for {month_year}": "{month_year}の記事",
    "Previous post": "一つ前の記事",
    "Previous": "前へ",
    "Publication date": "公開日",
    "RSS feed": "RSSフィード",
    "Read in English": "日本語で読む",
    "Read more": "続きを読む",
    "Skip to main content": "本文を読み飛ばす",
    "Source": "ソース",
    "Subcategories:": "サブカテゴリー",
    "Tags and Categories": "カテゴリーおよびタグ一覧",
    "Tags": "タグ",
    "Toggle navigation": "ナビゲーションを隠す",
    "Uncategorized": "カテゴリーなし",
    "Up": "上へ",
    "Updates": "更新",
    "Write your page here.": "ここに記事を記述してください。",
    "Write your post here.": "ここに記事を記述してください。",
    "old posts, page %d": "過去の記事 %dページ目",
    "page %d": "ページ%d",
    "updated": "更新日時",
}



# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "%d minuter kvar att läsa",
    "(active)": "(aktiv)",
    "Also available in:": "Även tillgänglig på:",
    "Archive": "Arkiv",
    "Atom feed": "",
    "Authors": "",
    "Categories": "Kategorier",
    "Comments": "Kommentarer",
    "LANGUAGE": "Svenska",
    "Languages:": "Språk:",
    "More posts about %s": "Fler inlägg om %s",
    "Newer posts": "Nya inlägg",
    "Next post": "Nästa inlägg",
    "Next": "",
    "No posts found.": "Inga inlägg hittade.",
    "Nothing found.": "Inget hittat.",
    "Older posts": "Äldre inlägg",
    "Original site": "Originalsida",
    "Posted:": "Publicerad:",
    "Posts about %s": "Inlägg om %s",
    "Posts by %s": "",
    "Posts for year %s": "Inlägg för år %s",
    "Posts for {month_day_year}": "Inlägg för {month_day_year}",
    "Posts for {month_year}": "Inlägg för {month_year}",
    "Previous post": "Föregående inlägg",
    "Previous": "",
    "Publication date": "Publiceringsdatum",
    "RSS feed": "RSS-flöde",
    "Read in English": "Läs på svenska",
    "Read more": "Läs mer",
    "Skip to main content": "Hoppa till huvudinnehåll",
    "Source": "Källa",
    "Subcategories:": "Underkategorier:",
    "Tags and Categories": "Taggar och Kategorier",
    "Tags": "Taggar",
    "Toggle navigation": "",
    "Uncategorized": "",
    "Up": "",
    "Updates": "",
    "Write your page here.": "Skriv din sida här.",
    "Write your post here.": "Skriv ditt inlägg här.",
    "old posts, page %d": "gamla inlägg, sida %d",
    "page %d": "sida %d",
    "updated": "",
}



# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "Залишилось читати %d хвилин",
    "(active)": "(активне)",
    "Also available in:": "Іншою мовою:",
    "Archive": "Архів",
    "Atom feed": "Стрічка у форматі Atom",
    "Authors": "Автори",
    "Categories": "Категорії",
    "Comments": "Коментарі",
    "LANGUAGE": "Українська",
    "Languages:": "Мови:",
    "More posts about %s": "Більше статей про  %s",
    "Newer posts": "Новіші статті",
    "Next post": "Наступна стаття",
    "Next": "Вперед",
    "No posts found.": "Не знайдено жодної статті",
    "Nothing found.": "Нічого не знайдено",
    "Older posts": "Старіші статті",
    "Original site": "Оригінал сайту",
    "Posted:": "Опублікована:",
    "Posts about %s": "Статті про %s",
    "Posts by %s": "Статті %s",
    "Posts for year %s": "Статті за %s рік",
    "Posts for {month_day_year}": "Статті за {month_day_year}",
    "Posts for {month_year}": "Статті за {month_year}",
    "Previous post": "Попередня стаття",
    "Previous": "Назад",
    "Publication date": "Дата публікації",
    "RSS feed": "Стрічка у форматі RSS",
    "Read in English": "Читати українською",
    "Read more": "Читати далі",
    "Skip to main content": "Перейти до основного матеріалу",
    "Source": "Джерело",
    "Subcategories:": "Підкатегорії:",
    "Tags and Categories": "Теги і категорії",
    "Tags": "Теги",
    "Toggle navigation": "Перемкнути навігацію",
    "Uncategorized": "Без категорії",
    "Up": "Нагору",
    "Updates": "Підписки",
    "Write your page here.": "Напишіть Вашу сторінку тут.",
    "Write your post here.": "Напишить Вашу статтю тут.",
    "old posts, page %d": "старі статті, сторінка %d",
    "page %d": "сторінка %d",
    "updated": "оновлено",
}



# -*- coding: utf-8 -*-

# Copyright © 2012-2024 Roberto Alsina and others.

# Permission is hereby granted, free of charge, to any
# person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the
# Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all copies or substantial portions of
# the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
# OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""Copy page sources into the output."""

import os

from nikola.plugin_categories import Task
from nikola import utils


class Sources(Task):
    """Copy page sources into the output."""

    name = "render_sources"

    def gen_tasks(self):
        """Publish the page sources into the output."""
        kw = {
            "translations": self.site.config["TRANSLATIONS"],
            "output_folder": self.site.config["OUTPUT_FOLDER"],
            "default_lang": self.site.config["DEFAULT_LANG"],
            "show_untranslated_posts": self.site.config['SHOW_UNTRANSLATED_POSTS'],
        }

        self.site.scan_posts()
        yield self.group_task()
        if self.site.config['COPY_SOURCES']:
            for lang in kw["translations"]:
                for post in self.site.timeline:
                    if not kw["show_untranslated_posts"] and lang not in post.translated_to:
                        continue
                    if post.meta('password'):
                        continue
                    output_name = os.path.join(
                        kw['output_folder'], post.destination_path(
                            lang, post.source_ext(True)))
                    # do not publish PHP sources
                    if post.source_ext(True) == post.compiler.extension():
                        continue
                    source = post.translated_source_path(lang)
                    if source is not None and os.path.isfile(source):
                        yield {
                            'basename': 'render_sources',
                            'name': os.path.normpath(output_name),
                            'file_dep': [source],
                            'targets': [output_name],
                            'actions': [(utils.copy_file, (source, output_name))],
                            'clean': True,
                            'uptodate': [utils.config_changed(kw, 'nikola.plugins.task.sources')],
                        }



# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "वाचण्यासाठी %d मिनिटे शिल्लक आहेत",
    "(active)": "(सक्रिय)",
    "Also available in:": "मध्ये देखील उपलब्ध:",
    "Archive": "संग्रह",
    "Atom feed": "अ‍ॅटम फीड",
    "Authors": "लेखक",
    "Categories": "श्रेणी",
    "Comments": "टिप्पण्या",
    "LANGUAGE": "मराठी",
    "Languages:": "भाषा:",
    "More posts about %s": "%s बद्दल अधिक पोस्ट",
    "Newer posts": "नवीन पोस्ट्स",
    "Next post": "पुढील पोस्ट",
    "Next": "पुढे",
    "No posts found.": "कोणतीही पोस्ट आढळली नाहीत",
    "Nothing found.": "काहीही सापडले नाही.",
    "Older posts": "जुने पोस्ट",
    "Original site": "मूळ साइट",
    "Posted:": "पोस्ट केले:",
    "Posts about %s": "%s बद्दल पोस्ट",
    "Posts by %s": "%s द्वारा पोस्ट केलेले",
    "Posts for year %s": "%s वर्षासाठी पोस्ट",
    "Posts for {month_day_year}": "{month_day_year} साठी पोस्ट्स",
    "Posts for {month_year}": "{month_year} साठी पोस्ट्स",
    "Previous post": "मागील पोस्ट",
    "Previous": "मागील",
    "Publication date": "प्रकाशन तारीख",
    "RSS feed": "आरएसएस फीड",
    "Read in English": "मराठी मध्ये वाचा",
    "Read more": "अधिक वाचा",
    "Skip to main content": "मुख्य सामग्रीकडे जा",
    "Source": "स्रोत",
    "Subcategories:": "उपश्रेणी:",
    "Tags and Categories": "टॅग्ज आणि श्रेण्या",
    "Tags": "टॅग्ज",
    "Toggle navigation": "नेव्हिगेशन टॉगल करा",
    "Uncategorized": "अवर्गीकृत",
    "Up": "वर",
    "Updates": "अद्यतने",
    "Write your page here.": "आपले पृष्ठ येथे लिहा.",
    "Write your post here.": "आपले पोस्ट येथे लिहा.",
    "old posts, page %d": "जुने पोस्ट, पृष्ठ %d",
    "page %d": "पृष्ठ %d",
    "updated": "अद्यतनित",
}



# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "%dminutas de lectura remanente",
    "(active)": "(active)",
    "Also available in:": "Anque disponibile in:",
    "Archive": "Archivo",
    "Atom feed": "Fluxo Atom",
    "Authors": "Authores",
    "Categories": "Categorias",
    "Comments": "Commentos",
    "LANGUAGE": "Interlingua",
    "Languages:": "Linguas:",
    "More posts about %s": "Plure entratas super %s",
    "Newer posts": "Entratas plus recente",
    "Next post": "Entrata successive",
    "Next": "Successive",
    "No posts found.": "Nulle entrata esseva trovate.",
    "Nothing found.": "Nihil esseva trovate.",
    "Older posts": "Entratas plus vetule",
    "Original site": "Sito original",
    "Posted:": "Publicate:",
    "Posts about %s": "Entratas super %s",
    "Posts by %s": "Entratas per %s",
    "Posts for year %s": "Entratas del anno %s",
    "Posts for {month_day_year}": "Entratas de {month_day_year}",
    "Posts for {month_year}": "Entratas de {month_year}",
    "Previous post": "Entrata precedente",
    "Previous": "Precendente",
    "Publication date": "Data de publication",
    "RSS feed": "Fluxo RSS",
    "Read in English": "Lege in interlingua",
    "Read more": "Lege plus",
    "Skip to main content": "Salta al contento principal",
    "Source": "Sorgente",
    "Subcategories:": "Subcategorias:",
    "Tags and Categories": "Etiquettas e categorias",
    "Tags": "Etiquettas",
    "Toggle navigation": "Commuta navigation",
    "Uncategorized": "Sin categoria",
    "Up": "In alto",
    "Updates": "Actualisationes",
    "Write your page here.": "Scribe tu pagina hic.",
    "Write your post here.": "Scribe tu entrata hic.",
    "old posts, page %d": "Vetule entratas, pagina %d",
    "page %d": "pagina %d",
    "updated": "actualisate",
}



# -*- coding: utf-8 -*-

# Copyright © 2012-2024 Roberto Alsina and others.

# Permission is hereby granted, free of charge, to any
# person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the
# Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all copies or substantial portions of
# the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
# OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""Logging support."""

import enum
import logging
import warnings

from nikola import DEBUG

__all__ = (
    "get_logger",
    "LOGGER",
)


# Handlers/formatters
class ApplicationWarning(Exception):
    """An application warning, raised in strict mode."""

    pass


class StrictModeExceptionHandler(logging.StreamHandler):
    """A logging handler that raises an exception on warnings."""

    def emit(self, record: logging.LogRecord) -> None:
        """Emit a logging record."""
        if record.levelno >= logging.WARNING:
            raise ApplicationWarning(self.format(record))


class ColorfulFormatter(logging.Formatter):
    """Stream handler with colors."""

    _colorful = False

    def format(self, record: logging.LogRecord) -> str:
        """Format a message and add colors to it."""
        message = super().format(record)
        return self.wrap_in_color(record).format(message)

    def wrap_in_color(self, record: logging.LogRecord) -> str:
        """Return the colorized string for this record."""
        if not self._colorful:
            return "{}"
        if record.levelno >= logging.ERROR:
            return "\033[1;31m{}\033[0m"
        elif record.levelno >= logging.WARNING:
            return "\033[1;33m{}\033[0m"
        elif record.levelno >= logging.INFO:
            return "\033[1m{}\033[0m"
        return "\033[37m{}\033[0m"


# Initial configuration
class LoggingMode(enum.Enum):
    """Logging mode options."""

    NORMAL = 0
    STRICT = 1
    QUIET = 2


def configure_logging(logging_mode: LoggingMode = LoggingMode.NORMAL) -> None:
    """Configure logging for Nikola.

    This method can be called multiple times, previous configuration will be overridden.
    """
    if DEBUG:
        logging.root.level = logging.DEBUG
    else:
        logging.root.level = logging.INFO

    if logging_mode == LoggingMode.QUIET:
        logging.root.handlers = []
        return

    handler = logging.StreamHandler()
    handler.setFormatter(
        ColorfulFormatter(
            fmt="[%(asctime)s] %(levelname)s: %(name)s: %(message)s",
            datefmt="%Y-%m-%d %H:%M:%S",
        )
    )

    handlers = [handler]
    if logging_mode == LoggingMode.STRICT:
        handlers.append(StrictModeExceptionHandler())

    logging.root.handlers = handlers


configure_logging()


# For compatibility with old code written with Logbook in mind
# TODO remove in v9
def patch_notice_level(logger: logging.Logger) -> logging.Logger:
    """Patch logger to issue WARNINGs with logger.notice."""
    logger.notice = logger.warning
    return logger


# User-facing loggers
def get_logger(name: str, handlers=None) -> logging.Logger:
    """Get a logger with handlers attached."""
    logger = logging.getLogger(name)
    if handlers is not None:
        for h in handlers:
            logger.addHandler(h)
    return patch_notice_level(logger)


LOGGER = get_logger("Nikola")


# Push warnings to logging
def showwarning(message, category, filename, lineno, file=None, line=None):
    """Show a warning (from the warnings module) to the user."""
    try:
        n = category.__name__
    except AttributeError:
        n = str(category)
    get_logger(n).warning("{0}:{1}: {2}".format(filename, lineno, message))


warnings.showwarning = showwarning



# -*- coding: utf-8 -*-

# Copyright © 2014-2024 Puneeth Chaganti and others.

# Permission is hereby granted, free of charge, to any
# person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the
# Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all copies or substantial portions of
# the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
# OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""Deploy site to GitHub Pages."""

import os
import subprocess
from textwrap import dedent

from nikola.plugin_categories import Command
from nikola.plugins.command.check import real_scan_files
from nikola.utils import req_missing, clean_before_deployment
from nikola.__main__ import main
from nikola import __version__


def uni_check_output(*args, **kwargs):
    """Run command and return output as Unicode (UTf-8)."""
    o = subprocess.check_output(*args, **kwargs)
    return o.decode('utf-8')


def check_ghp_import_installed():
    """Check if ghp-import is installed."""
    try:
        subprocess.check_output(['ghp-import', '-h'])
    except OSError:
        # req_missing defaults to `python=True` — and it’s meant to be like this.
        # `ghp-import` is installed via pip, but the only way to use it is by executing the script it installs.
        req_missing(['ghp-import'], 'deploy the site to GitHub Pages')


class DeployFailedException(Exception):
    """An internal exception for deployment errors."""

    pass


class CommandGitHubDeploy(Command):
    """Deploy site to GitHub Pages."""

    name = 'github_deploy'

    doc_usage = '[-m COMMIT_MESSAGE]'
    doc_purpose = 'deploy the site to GitHub Pages'
    doc_description = dedent(
        """\
        This command can be used to deploy your site to GitHub Pages. It uses ghp-import to do this task. It also optionally commits to the source branch.

        Configuration help: https://getnikola.com/handbook.html#deploying-to-github"""
    )
    cmd_options = [
        {
            'name': 'commit_message',
            'short': 'm',
            'long': 'message',
            'default': 'Nikola auto commit.',
            'type': str,
            'help': 'Commit message',
        },
    ]

    def _execute(self, options, args):
        """Run the deployment."""
        # Check if ghp-import is installed
        check_ghp_import_installed()

        # Build before deploying
        build = main(['build'])
        if build != 0:
            self.logger.error('Build failed, not deploying to GitHub')
            return build

        # Clean non-target files
        only_on_output, _ = real_scan_files(self.site)
        for f in only_on_output:
            os.unlink(f)

        # Remove drafts and future posts if requested (Issue #2406)
        undeployed_posts = clean_before_deployment(self.site)
        if undeployed_posts:
            self.logger.warning("Deleted {0} posts due to DEPLOY_* settings".format(len(undeployed_posts)))

        # Commit and push
        return self._commit_and_push(options['commit_message'])

    def _run_command(self, command, xfail=False):
        """Run a command that may or may not fail."""
        self.logger.info("==> {0}".format(command))
        try:
            subprocess.check_call(command)
            return 0
        except subprocess.CalledProcessError as e:
            if xfail:
                return e.returncode
            self.logger.error(
                'Failed GitHub deployment -- command {0} '
                'returned {1}'.format(e.cmd, e.returncode)
            )
            raise DeployFailedException(e.returncode)

    def _commit_and_push(self, commit_first_line):
        """Commit all the files and push."""
        source = self.site.config['GITHUB_SOURCE_BRANCH']
        deploy = self.site.config['GITHUB_DEPLOY_BRANCH']
        remote = self.site.config['GITHUB_REMOTE_NAME']
        autocommit = self.site.config['GITHUB_COMMIT_SOURCE']
        try:
            if autocommit:
                commit_message = (
                    '{0}\n\n'
                    'Nikola version: {1}'.format(commit_first_line, __version__)
                )
                e = self._run_command(['git', 'checkout', source], True)
                if e != 0:
                    self._run_command(['git', 'checkout', '-b', source])
                self._run_command(['git', 'add', '.'])
                # Figure out if there is anything to commit
                e = self._run_command(['git', 'diff-index', '--quiet', 'HEAD'], True)
                if e != 0:
                    self._run_command(['git', 'commit', '-am', commit_message])
                else:
                    self.logger.info('Nothing to commit to source branch.')

            try:
                source_commit = uni_check_output(['git', 'rev-parse', source])
            except subprocess.CalledProcessError:
                try:
                    source_commit = uni_check_output(['git', 'rev-parse', 'HEAD'])
                except subprocess.CalledProcessError:
                    source_commit = '?'

            commit_message = (
                '{0}\n\n'
                'Source commit: {1}'
                'Nikola version: {2}'.format(commit_first_line, source_commit, __version__)
            )
            output_folder = self.site.config['OUTPUT_FOLDER']

            command = ['ghp-import', '-n', '-m', commit_message, '-p', '-r', remote, '-b', deploy, output_folder]

            self._run_command(command)

            if autocommit:
                self._run_command(['git', 'push', '-u', remote, source])
        except DeployFailedException as e:
            return e.args[0]

        self.logger.info("Successful deployment")
